==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/AutoFitterOptions.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class AutoFitterOptions (SpireObject) :
    """

    """
    @property
    def AutoFitMergedCells(self)->bool:
        """
    <summary>
        Indicates whether auto fit row height when the cells is merged in a row.
            The default value is false.
    </summary>
        """
        GetDllLibXls().AutoFitterOptions_get_AutoFitMergedCells.argtypes=[c_void_p]
        GetDllLibXls().AutoFitterOptions_get_AutoFitMergedCells.restype=c_bool
        ret = GetDllLibXls().AutoFitterOptions_get_AutoFitMergedCells(self.Ptr)
        return ret

    @AutoFitMergedCells.setter
    def AutoFitMergedCells(self, value:bool):
        GetDllLibXls().AutoFitterOptions_set_AutoFitMergedCells.argtypes=[c_void_p, c_bool]
        GetDllLibXls().AutoFitterOptions_set_AutoFitMergedCells(self.Ptr, value)

    @property
    def OnlyAuto(self)->bool:
        """
    <summary>
        Indicates whether only fit the rows which height are not customed.
            The default value is false.
    </summary>
        """
        GetDllLibXls().AutoFitterOptions_get_OnlyAuto.argtypes=[c_void_p]
        GetDllLibXls().AutoFitterOptions_get_OnlyAuto.restype=c_bool
        ret = GetDllLibXls().AutoFitterOptions_get_OnlyAuto(self.Ptr)
        return ret

    @OnlyAuto.setter
    def OnlyAuto(self, value:bool):
        GetDllLibXls().AutoFitterOptions_set_OnlyAuto.argtypes=[c_void_p, c_bool]
        GetDllLibXls().AutoFitterOptions_set_OnlyAuto(self.Ptr, value)

    @property
    def IgnoreHidden(self)->bool:
        """
    <summary>
        Ingored the hidden rows/columns.
            The default value is false.
    </summary>
        """
        GetDllLibXls().AutoFitterOptions_get_IgnoreHidden.argtypes=[c_void_p]
        GetDllLibXls().AutoFitterOptions_get_IgnoreHidden.restype=c_bool
        ret = GetDllLibXls().AutoFitterOptions_get_IgnoreHidden(self.Ptr)
        return ret

    @IgnoreHidden.setter
    def IgnoreHidden(self, value:bool):
        GetDllLibXls().AutoFitterOptions_set_IgnoreHidden.argtypes=[c_void_p, c_bool]
        GetDllLibXls().AutoFitterOptions_set_IgnoreHidden(self.Ptr, value)

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/AutoFitterOptions.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class AutoFitterOptions (SpireObject) :
    """

    """
    @property
    def AutoFitMergedCells(self)->bool:
        """
    <summary>
        Indicates whether auto fit row height when the cells is merged in a row.
            The default value is false.
    </summary>
        """
        GetDllLibXls().AutoFitterOptions_get_AutoFitMergedCells.argtypes=[c_void_p]
        GetDllLibXls().AutoFitterOptions_get_AutoFitMergedCells.restype=c_bool
        ret = CallCFunction(GetDllLibXls().AutoFitterOptions_get_AutoFitMergedCells, self.Ptr)
        return ret

    @AutoFitMergedCells.setter
    def AutoFitMergedCells(self, value:bool):
        GetDllLibXls().AutoFitterOptions_set_AutoFitMergedCells.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibXls().AutoFitterOptions_set_AutoFitMergedCells, self.Ptr, value)

    @property
    def OnlyAuto(self)->bool:
        """
    <summary>
        Indicates whether only fit the rows which height are not customed.
            The default value is false.
    </summary>
        """
        GetDllLibXls().AutoFitterOptions_get_OnlyAuto.argtypes=[c_void_p]
        GetDllLibXls().AutoFitterOptions_get_OnlyAuto.restype=c_bool
        ret = CallCFunction(GetDllLibXls().AutoFitterOptions_get_OnlyAuto, self.Ptr)
        return ret

    @OnlyAuto.setter
    def OnlyAuto(self, value:bool):
        GetDllLibXls().AutoFitterOptions_set_OnlyAuto.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibXls().AutoFitterOptions_set_OnlyAuto, self.Ptr, value)

    @property
    def IgnoreHidden(self)->bool:
        """
    <summary>
        Ingored the hidden rows/columns.
            The default value is false.
    </summary>
        """
        GetDllLibXls().AutoFitterOptions_get_IgnoreHidden.argtypes=[c_void_p]
        GetDllLibXls().AutoFitterOptions_get_IgnoreHidden.restype=c_bool
        ret = CallCFunction(GetDllLibXls().AutoFitterOptions_get_IgnoreHidden, self.Ptr)
        return ret

    @IgnoreHidden.setter
    def IgnoreHidden(self, value:bool):
        GetDllLibXls().AutoFitterOptions_set_IgnoreHidden.argtypes=[c_void_p, c_bool]
        CallCFunction(GetDllLibXls().AutoFitterOptions_set_IgnoreHidden, self.Ptr, value)
